@@ -6,9 +6,11 @@ Anything imported here will be available in the default Pynecone import as `pc.*
 from .app import App
 from .base import Base
 from .components import *
+from .components.component import custom_component as component
+from .components.graphing.victory import data
 from .config import Config
 from .constants import Env
-from .event import console_log, redirect, window_alert
+from .event import EventChain, console_log, redirect, window_alert
 from .middleware import Middleware
 from .model import Model, session
 from .state import ComputedVar as var
