@@ -13,7 +13,6 @@ import signal
 import string
 import subprocess
 import sys
-import uvicorn
 from collections import defaultdict
 from subprocess import PIPE
 from types import ModuleType
@@ -29,9 +28,11 @@ from typing import (
     Type,
     Union,
 )
+from urllib.parse import urlparse
 
 import plotly.graph_objects as go
 import typer
+import uvicorn
 from plotly.io import to_json
 from redis import Redis
 from rich.console import Console
@@ -376,6 +377,21 @@ def create_config(app_name: str):
         f.write(templates.PCCONFIG.format(app_name=app_name))
 
 
+def initialize_gitignore():
+    """Initialize the template .gitignore file."""
+    # The files to add to the .gitignore file.
+    files = constants.DEFAULT_GITIGNORE
+
+    # Subtract current ignored files.
+    if os.path.exists(constants.GITIGNORE_FILE):
+        with open(constants.GITIGNORE_FILE, "r") as f:
+            files -= set(f.read().splitlines())
+
+    # Add the new files to the .gitignore file.
+    with open(constants.GITIGNORE_FILE, "a") as f:
+        f.write(join(files))
+
+
 def initialize_app_directory(app_name: str):
     """Initialize the app directory on pc init.
 
@@ -483,7 +499,15 @@ def setup_frontend():
     install_frontend_packages()
 
     # Link the assets folder.
-    ln(src=os.path.join("..", constants.APP_ASSETS_DIR), dest=constants.WEB_ASSETS_DIR)
+    if platform.system() == "Windows":
+        # copy asset files to public folder
+        mkdir(constants.WEB_ASSETS_DIR)
+        cp(src=constants.APP_ASSETS_DIR, dest=constants.WEB_ASSETS_DIR)
+    else:
+        ln(
+            src=os.path.join("..", constants.APP_ASSETS_DIR),
+            dest=constants.WEB_ASSETS_DIR,
+        )
 
 
 def run_frontend(app: App):
@@ -500,7 +524,10 @@ def run_frontend(app: App):
 
     # Run the frontend in development mode.
     console.rule("[bold green]App Running")
-    subprocess.Popen([get_package_manager(), "run", "dev"], cwd=constants.WEB_DIR)
+    os.environ["PORT"] = get_config().port
+    subprocess.Popen(
+        [get_package_manager(), "run", "dev"], cwd=constants.WEB_DIR, env=os.environ
+    )
 
 
 def run_frontend_prod(app: App):
@@ -515,8 +542,12 @@ def run_frontend_prod(app: App):
     # Export the app.
     export_app(app)
 
+    os.environ["PORT"] = get_config().port
+
     # Run the frontend in production mode.
-    subprocess.Popen([get_package_manager(), "run", "prod"], cwd=constants.WEB_DIR)
+    subprocess.Popen(
+        [get_package_manager(), "run", "prod"], cwd=constants.WEB_DIR, env=os.environ
+    )
 
 
 def get_num_workers() -> int:
@@ -533,6 +564,19 @@ def get_num_workers() -> int:
     return (os.cpu_count() or 1) * 2 + 1
 
 
+def get_api_port() -> int:
+    """Get the API port.
+
+    Returns:
+        The API port.
+    """
+    port = urlparse(get_config().api_url).port
+    if port is None:
+        port = urlparse(constants.API_URL).port
+    assert port is not None
+    return port
+
+
 def run_backend(app_name: str, loglevel: constants.LogLevel = constants.LogLevel.ERROR):
     """Run the backend.
 
@@ -543,6 +587,7 @@ def run_backend(app_name: str, loglevel: constants.LogLevel = constants.LogLevel
     uvicorn.run(
         f"{app_name}:{constants.APP_VAR}.{constants.API_VAR}",
         host=constants.BACKEND_HOST,
+        port=get_api_port(),
         log_level=loglevel,
         reload=True,
     )
@@ -559,6 +604,8 @@ def run_backend_prod(
     """
     num_workers = get_num_workers()
     command = constants.RUN_BACKEND_PROD + [
+        "--bind",
+        f"0.0.0.0:{get_api_port()}",
         "--workers",
         str(num_workers),
         "--threads",
@@ -621,10 +668,8 @@ def to_camel_case(text: str) -> str:
     return prefix + camel
 
 
-def to_title(text: str) -> str:
-    """Convert a string from snake case to a title.
-
-    Each word is converted to title case and separated by a space.
+def to_title_case(text: str) -> str:
+    """Convert a string from snake case to title case.
 
     Args:
         text: The string to convert.
@@ -632,7 +677,7 @@ def to_title(text: str) -> str:
     Returns:
         The title case string.
     """
-    return " ".join(word.capitalize() for word in text.split("_"))
+    return "".join(word.capitalize() for word in text.split("_"))
 
 
 WRAP_MAP = {
@@ -726,27 +771,6 @@ def indent(text: str, indent_level: int = 2) -> str:
     return os.linesep.join(f"{' ' * indent_level}{line}" for line in lines) + os.linesep
 
 
-def get_page_path(path: str) -> str:
-    """Get the path of the compiled JS file for the given page.
-
-    Args:
-        path: The path of the page.
-
-    Returns:
-        The path of the compiled JS file.
-    """
-    return os.path.join(constants.WEB_PAGES_DIR, path + constants.JS_EXT)
-
-
-def get_theme_path() -> str:
-    """Get the path of the base theme style.
-
-    Returns:
-        The path of the theme style.
-    """
-    return os.path.join(constants.WEB_UTILS_DIR, constants.THEME + constants.JS_EXT)
-
-
 def get_path_args(path: str) -> List[str]:
     """Get the path arguments for the given path.
 
@@ -777,18 +801,6 @@ def get_path_args(path: str) -> List[str]:
     return args
 
 
-def write_page(path: str, code: str):
-    """Write the given code to the given path.
-
-    Args:
-        path: The path to write the code to.
-        code: The code to write.
-    """
-    mkdir(os.path.dirname(path))
-    with open(path, "w") as f:
-        f.write(code)
-
-
 def format_route(route: str):
     """Format the given route.
 
