@@ -161,7 +161,9 @@ class Var(ABC):
             else:
                 type_ = Any
         else:
-            raise TypeError("Var does not support indexing.")
+            raise TypeError(
+                f"Var {self.name} of type {self.type_} does not support indexing."
+            )
 
         return BaseVar(
             name=f"{self.name}[{i}]",
@@ -277,6 +279,22 @@ class Var(ABC):
         """
         return self.operation(fn="Math.abs")
 
+    def length(self) -> Var:
+        """Get the length of a list var.
+
+        Returns:
+            A var with the absolute value.
+
+        Raises:
+            TypeError: If the var is not a list.
+        """
+        if not utils._issubclass(self.type_, List):
+            raise TypeError(f"Cannot get length of non-list var {self}.")
+        return BaseVar(
+            name=f"{self.full_name}.length",
+            type_=int,
+        )
+
     def __eq__(self, other: Var) -> Var:
         """Perform an equality comparison.
 
